@@ -1,8 +1,25 @@
 import orjson
+
 from confluent_kafka.serialization import Deserializer
+from confluent_kafka.serialization import Serializer
 from confluent_kafka.serialization import SerializationError
 
 
+# pylint: disable=R0903
+class JSONSimpleSerializer(Serializer):
+    """
+    Serializes a Python object to JSON formatted string.
+    """
+    def __call__(self, obj, ctx):
+        if obj is None:
+            return None
+
+        try:
+            return orjson.dumps(obj)  # pylint: disable=E1101
+        except orjson.JSONDecodeError as e:  # pylint: disable=E1101
+            raise SerializationError(e)
+
+
 # pylint: disable=R0903
 class JSONSimpleDeserializer(Deserializer):
     """
@@ -26,4 +43,4 @@ class JSONSimpleDeserializer(Deserializer):
         try:
             return orjson.loads(value)  # pylint: disable=E1101
         except orjson.JSONDecodeError as e: # pylint: disable=E1101
-            raise SerializationError(str(e))
+            raise SerializationError(e)
